@@ -245,12 +245,10 @@ TAG_EMBEDDING_LEN = 384
 
 
 class TagReader:
-    def __init__(self):
+    def __init__(self, ing_model):
         tag_model_path = os.path.join(ROOT_DIR, "models", "tag_embedding.model")
         self.tag_model = SentenceTransformer(tag_model_path)
-
-        ing_model_path = os.path.join(ROOT_DIR, "models", "ing_embedding.model")
-        self.ing_model = Word2Vec.load(ing_model_path)
+        self.ing_model = ing_model
 
         embedding_csv_path = os.path.join(
             ROOT_DIR, "data", "mean_ing_embedding_per_tag.csv"
@@ -312,4 +310,4 @@ class TagReader:
         mask = values != 0
         values[mask] = 1.0
 
-        return {"values": np.array(values), "model": search_result.payload["models"]}
+        return {"values": np.array(values), "models": search_result.payload["models"]}
